@@ -5,8 +5,8 @@ our $AUTHORITY = 'cpan:XSAWYERX';
 use strict;
 use warnings;
 
-use Perl::Critic::Utils qw(:severities :classification :ppi);
 use parent 'Perl::Critic::Policy';
+use Perl::Critic::Utils qw(:severities :classification :ppi);
 
 our $VERSION = '0.001';
 
@@ -17,7 +17,7 @@ use constant 'EXPL' => 'Using an array slice returns a list, '
                      . 'single value access, not array slice.';
 
 sub supported_parameters { () }
-sub default_severity     {$SEVERITY_HIGHEST}
+sub default_severity     {$SEVERITY_HIGH}
 sub default_themes       {'bugs'}
 sub applies_to           {'PPI::Token::Symbol'}
 
@@ -32,21 +32,35 @@ sub violates {
         or return ();
 
     my $next = $elem->snext_sibling;
-    $next->isa('PPI::Structure::Subscript')
+    $next && $next->isa('PPI::Structure::Subscript')
         or return ();
 
     my @children = $next->children;
     @children > 1
         and return ();
 
-    @children == 1
-        and return $self->violation( DESC(), EXPL(), $next );
+    @children == 0
+        and return $self->violation( 'Empty subscript',
+        'You have an array slice with an empty subscript', $next, );
 
-    return $self->violation(
-        'Empty subscript',
-        'You have an array slice with an empty subscript',
-        $next,
-    );
+    my $child          = $children[0];
+    my @child_elements = $child->elements;
+
+    @child_elements > 1
+        and return ();
+
+    @children == 0
+        and return $self->violation( 'Empty expression subscript',
+        'You have an array slice with an empty expression subscript',
+        $next, );
+
+    my $element = $child_elements[0];
+
+    # @foo[1]
+    $element->isa('PPI::Token::Number')
+        or return ();
+
+    return $self->violation( DESC(), EXPL(), $next );
 }
 
 1;
@@ -63,14 +77,13 @@ Perl::Critic::Policy::ValuesAndExpressions::ProhibitSingleArgArraySlice - Prohib
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
 When using an array slice C<@foo[]>, you can retrieve multiple values by
 giving more than one index. Sometimes, however, either due to typo or
-inexperience, we might only provide a single index. This is a problem due
-to the list context enforced.
+inexperience, we might only provide a single index.
 
 Perl warns you about this, but it will only do this during runtime. This
 policy allows you to detect it statically.
@@ -81,7 +94,7 @@ policy allows you to detect it statically.
   # List context, multiple values retrieved
   my @values    = @array[ $index1, $index2 ] # ok
 
-  # List context, single value retrived - the size of the array!
+  # Scalar context, single value retrived (the last item in the array)
   # Perl will warn you, but only in runtime
   my $value     = @array[$index];            # not ok
 
